@@ -6,11 +6,11 @@
  * in <winsock.h>, and are common to WinSock Versions 1.1 and 2.
  *
  *
- * $Id: winsock2.h,v a346ddcc5d76 2017/11/28 13:28:34 keith $
+ * $Id: winsock2.h,v a14ae09b813e 2019/02/03 15:47:20 keith $
  *
  * Contributed by the WINE Project.
  * Adaptation by Mumit Khan <khan@xraylith.wisc.edu>
- * Copyright (C) 1998-2005, 2011, 2016, 2017, MinGW.org Project
+ * Copyright (C) 1998-2005, 2011, 2016, 2017, 2019, MinGW.org Project
  *
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -42,6 +42,13 @@
 #pragma GCC system_header
 #define _WINSOCK2_H
 
+/* This is MinGW's preferred WinSock default choice; having made it, we
+ * MUST now ensure that the __USE_MINGW_WINSOCK_DEFAULT selector doesn't
+ * persist beyond this point, since it would interfere with inclusion of
+ * common content from <winsock.h>
+ */
+#undef __USE_MINGW_WINSOCK_DEFAULT
+
 #ifdef _WINSOCK_H  /* included prematurely */
 /* Oops!  <winsock.h> appears to have been included already, which now
  * precludes any use of WinSock v2 protocol.
